@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use strict;
 use warnings;
@@ -146,7 +146,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -183,15 +183,18 @@ of an C<E A D G B E> tuned guitar.
 
 =head2 voicing_file
 
+  $file = $mcg->voicing_file;
+
 The CSV file with which to find the MIDI numbered chord voicings.
 
-If not given, L<File::ShareDir> is used.
+If not given, the installed L<File::ShareDir> CSV file is used.
 
 =head2 chords
 
   $chords = $mcg->chords;
 
-Computed attribute available after construction.
+Computed attribute, containing the fingerings and voicings for all
+known chords, available after construction.
 
 =head1 METHODS
 
@@ -238,16 +241,16 @@ diagrams to figure out the exact neck positions.
 Here is an example of the voicing CSV file which can be found with the
 B<voicing_file> attribute:
 
-  C,48,52,55,60,,
-  C,48,55,60,64,67,
-  C,48,52,55,60,64,72
-  C,48,55,60,64,67,72
-  C,60,67,72,76,,
-  C7,48,52,58,60,64,
-  C7,48,55,58,64,67,
-  C7,48,55,58,64,67,72
-  C7,48,52,55,60,64,70
-  C7,60,67,70,76,,
+  C,x32010-1,48,52,55,60,,
+  C,x13331-3,48,55,60,64,67,
+  C,431114-5,48,52,55,60,64,72
+  C,133211-8,48,55,60,64,67,72
+  C,xx1343-10,60,67,72,76,,
+  C7,x32310-1,48,52,58,60,64,
+  C7,x13131-3,48,55,58,64,67,
+  C7,431112-5,48,52,55,60,64,70
+  C7,131211-8,48,55,58,64,70,72
+  C7,xx1323-10,60,67,70,76,,
   ...
 
 Check out the link in the L</"SEE ALSO"> section for the chord shapes
@@ -257,6 +260,8 @@ used to create this.
 
 The F<t/01-methods.t> and F<eg/*> files in this distribution
 
+The CSV of chords used by this module (with the C<voicing_file> attribute)
+
 L<File::ShareDir>
 
 L<List::Util>
